@@ -21,6 +21,8 @@
 """Module application provides class Application."""
 
 from asyncio import sleep
+from functools import partial
+from json import dumps
 
 from aiohttp import WSMsgType, web
 from asyncpg.exceptions import (
@@ -389,4 +391,4 @@ class Application:
 
         stream_event = event.stream_event()
         for ws in self.ws_list:  # pylint: disable=invalid-name
-            await ws.send_json(stream_event)
+            await ws.send_json(stream_event, dumps=partial(dumps, default=str))
