@@ -30,9 +30,11 @@ class Attribute(Field):
     (classes derived from JSON_API).
     """
 
-    def __init__(self, type_):
+    def __init__(self, type_, *, nullable=False, default=None):
         self.type_ = type_
         self.name = ''  # Overridden in JSON_API.__init_subclass__
+        self.nullable = nullable
+        self.default = default
 
     def filter_condition(self, values):
         sql_values = [
@@ -47,7 +49,14 @@ class Attribute(Field):
             A string containing the SQL column definition for this attribute.
         """
 
-        return f'{self.name} {self.type_.name}'
+        if self.nullable:
+            if self.default:
+                return f'{self.name} {self.type_.name} DEFAULT {self.default}'
+            return f'{self.name} {self.type_.name}'
+        if self.default:
+            return (f'{self.name} {self.type_.name} '
+                    f'NOT NULL DEFAULT {self.default}')
+        return f'{self.name} {self.type_.name} NOT NULL'
 
     def __str__(self):
         return self.name
