@@ -308,25 +308,26 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
         if local_ids is None and filters is None and page == {}:
             partial = ''
         else:
-            sort = query['sort']
             if filters:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)}")
+                where_clause = f' WHERE {" AND ".join(filters)}'
             else:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = f"SELECT id FROM data.{self.table.name}"
+                where_clause = ''
+
+            sort = query['sort']
+            if sort:
+                order_by_clause = f' ORDER BY {", ".join(sort)}'
+            else:
+                order_by_clause = ''
+
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
-                stmt += f' LIMIT {limit} OFFSET {offset}'
+                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+            else:
+                limit_offset_clause = ''
+
+            stmt = (f'SELECT id FROM data.{self.table.name}'
+                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
             partial = f' WHERE id IN ({stmt})'
         return f'SELECT {self.lfkey} FROM data.{self.table.name}{partial}'
 
@@ -368,30 +369,30 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         filters = query['filters']
         page = query['page']
         if local_ids is None and filters is None and page == {}:
-            partial = ' IS NOT NULL'
+            where = f'WHERE {self.rfkey} IS NOT NULL'
         else:
-            sort = query['sort']
             if filters:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)}")
+                where_clause = f' WHERE {" AND ".join(filters)}'
             else:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = f"SELECT id FROM data.{self.table.name}"
+                where_clause = ''
+
+            sort = query['sort']
+            if sort:
+                order_by_clause = f' ORDER BY {", ".join(sort)}'
+            else:
+                order_by_clause = ''
+
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
-                stmt += f' LIMIT {limit} OFFSET {offset}'
-            partial = f' IN ({stmt})'
-        return (f'SELECT id FROM data.{self.rtable.name} '
-                f'WHERE {self.rfkey}{partial}')
+                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+            else:
+                limit_offset_clause = ''
+
+            stmt = (f'SELECT id FROM data.{self.table.name}'
+                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
+            where = f'WHERE {self.rfkey} IN ({stmt})'
+        return f'SELECT id FROM data.{self.rtable.name} {where}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
@@ -753,30 +754,30 @@ class OneToManyRelationship(ToManyRelationship):
         filters = query['filters']
         page = query['page']
         if local_ids is None and filters is None and page == {}:
-            partial = ' IS NOT NULL'
+            where = f'WHERE {self.rfkey} IS NOT NULL'
         else:
-            sort = query['sort']
             if filters:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)}")
+                where_clause = f' WHERE {" AND ".join(filters)}'
             else:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = f"SELECT id FROM data.{self.table.name}"
+                where_clause = ''
+
+            sort = query['sort']
+            if sort:
+                order_by_clause = f' ORDER BY {", ".join(sort)}'
+            else:
+                order_by_clause = ''
+
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
-                stmt += f' LIMIT {limit} OFFSET {offset}'
-            partial = f' IN ({stmt})'
-        return (f'SELECT id FROM data.{self.rtable.name} '
-                f'WHERE {self.rfkey}{partial}')
+                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+            else:
+                limit_offset_clause = ''
+
+            stmt = (f'SELECT id FROM data.{self.table.name}'
+                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
+            where = f'WHERE {self.rfkey} IN ({stmt})'
+        return f'SELECT id FROM data.{self.rtable.name} {where}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
@@ -1148,29 +1149,30 @@ class ManyToOneRelationship(LocalRelationship, ToOneRelationship):
         filters = query['filters']
         page = query['page']
         if local_ids is None and filters is None and page == {}:
-            partial = ''
+            where = ''
         else:
-            sort = query['sort']
             if filters:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)}")
+                where_clause = f' WHERE {" AND ".join(filters)}'
             else:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = f"SELECT id FROM data.{self.table.name}"
+                where_clause = ''
+
+            sort = query['sort']
+            if sort:
+                order_by_clause = f' ORDER BY {", ".join(sort)}'
+            else:
+                order_by_clause = ''
+
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
-                stmt += f' LIMIT {limit} OFFSET {offset}'
-            partial = f' WHERE id IN ({stmt})'
-        return f'SELECT {self.lfkey} FROM data.{self.table.name}{partial}'
+                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+            else:
+                limit_offset_clause = ''
+
+            stmt = (f'SELECT id FROM data.{self.table.name}'
+                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
+            where = f' WHERE id IN ({stmt})'
+        return f'SELECT {self.lfkey} FROM data.{self.table.name}{where}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
@@ -1213,30 +1215,30 @@ class ManyToManyRelationship(ToManyRelationship):
         filters = query['filters']
         page = query['page']
         if local_ids is None and filters is None and page == {}:
-            partial = ' IS NOT NULL'
+            where = f'WHERE {self.lafkey} IS NOT NULL'
         else:
-            sort = query['sort']
             if filters:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"WHERE {' AND '.join(filters)}")
+                where_clause = f' WHERE {" AND ".join(filters)}'
             else:
-                if sort:
-                    stmt = (f"SELECT id FROM data.{self.table.name} "
-                            f"ORDER BY {', '.join(sort)}")
-                else:
-                    stmt = f"SELECT id FROM data.{self.table.name}"
+                where_clause = ''
+
+            sort = query['sort']
+            if sort:
+                order_by_clause = f' ORDER BY {", ".join(sort)}'
+            else:
+                order_by_clause = ''
+
             if page:
                 limit = page['size']
                 offset = page['number'] * limit
-                stmt += f' LIMIT {limit} OFFSET {offset}'
-            partial = f' IN ({stmt})'
-        return (f'SELECT {self.rafkey} FROM data.{self.atable.name} '
-                f'WHERE {self.lafkey}{partial}')
+                limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+            else:
+                limit_offset_clause = ''
+
+            stmt = (f'SELECT id FROM data.{self.table.name}'
+                    f'{where_clause}{order_by_clause}{limit_offset_clause}')
+            where = f'WHERE {self.lafkey} IN ({stmt})'
+        return f'SELECT {self.rafkey} FROM data.{self.atable.name} {where}'
 
     def object_remote_ids(self, local_ids=None):
         if local_ids is None:
