@@ -23,7 +23,6 @@
 from abc import abstractmethod
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
-from json import loads
 from re import compile as re_compile
 
 from asyncpg.exceptions import (
@@ -57,7 +56,6 @@ from ajsonapi.postgres import (
 )
 from ajsonapi.query import parse_fields, parse_page, query_has_parameter
 from ajsonapi.responses import document_response, no_content_response
-from ajsonapi.types import Json
 from ajsonapi.uri.resource import Resource
 
 RE_FILTER = re_compile(r'filter\[([^\]]*)\]')
@@ -180,10 +178,11 @@ class Collection(Resource):
                 field_name = match.group(1)
                 try:
                     field = getattr(self.table.___, field_name)
-                    condition = field.filter_condition(value)
                 except AttributeError:
                     errors.append(FilterInvalidFieldError(field_name))
                     continue
+                else:
+                    condition = field.filter_condition(value)
                 return_list.append(condition)
         return return_list
 
@@ -243,10 +242,6 @@ class Collection(Resource):
         await env.run()
         id_name = id_number_to_name(env.id_number)
         document.data['id'] = id_name
-        for attr_name, value in document.attributes.items():
-            attr = self.table.attributes_by_name[attr_name]
-            if attr.type_ == Json:
-                document.attributes[attr_name] = loads(value)
         path = f'{self.path()}/{id_name}'
         document.data['links'] = {'self': path}
         event = CreateEvent(document.data)
@@ -313,13 +308,16 @@ class Collection(Resource):
         else:
             stmt = (f'INSERT INTO data.{self.table.name} '
                     'DEFAULT VALUES RETURNING id')
+        attribute_values = []
+        for attr_name, value in env.attributes.items():
+            attr = self.table.attributes_by_name[attr_name]
+            attribute_values.append(attr.type_.to_sql(value))
         try:
             async with env.lock:
                 async with env.connection.transaction():
-                    log.debug(f'{stmt}: {env.attributes.values()}, '
-                              f'{lfkey_values}')
+                    log.debug(f'{stmt}: {attribute_values}, ' f'{lfkey_values}')
                     env.id_number = await env.connection.fetchval(
-                        stmt, *env.attributes.values(), *lfkey_values)
+                        stmt, *attribute_values, *lfkey_values)
                     env.event.set()
         except ForeignKeyViolationError as exc:
             env.cancel()
@@ -408,31 +406,29 @@ class Collection(Resource):
                 (str(col) for col in self.table.columns if col in fields[self]))
         else:
             columns = (str(col) for col in self.table.columns)
+
         filters = env.query['filters']
-        sort = env.query['sort']
         if filters:
-            if sort:
-                stmt = (
-                    f"SELECT {', '.join(columns)} FROM data.{self.table.name} "
-                    f"WHERE {' AND '.join(filters)} "
-                    f"ORDER BY {', '.join(sort)}")
-            else:
-                stmt = (
-                    f"SELECT {', '.join(columns)} FROM data.{self.table.name} "
-                    f"WHERE {' AND '.join(filters)}")
+            where_clause = f' WHERE {" AND ".join(filters)}'
         else:
-            if sort:
-                stmt = (
-                    f"SELECT {', '.join(columns)} FROM data.{self.table.name} "
-                    f"ORDER BY {', '.join(sort)}")
-            else:
-                stmt = (
-                    f"SELECT {', '.join(columns)} FROM data.{self.table.name}")
+            where_clause = ''
+
+        sort = env.query['sort']
+        if sort:
+            order_by_clause = f' ORDER BY {", ".join(sort)}'
+        else:
+            order_by_clause = ''
+
         page = env.query['page']
         if page:
             limit = page['size']
             offset = page['number'] * limit
-            stmt += f' LIMIT {limit} OFFSET {offset}'
+            limit_offset_clause = f' LIMIT {limit} OFFSET {offset}'
+        else:
+            limit_offset_clause = ''
+
+        stmt = (f'SELECT {", ".join(columns)} FROM data.{self.table.name}'
+                f'{where_clause}{order_by_clause}{limit_offset_clause}')
         async with env.lock:
             log.debug(stmt)
             records = await env.connection.fetch(stmt)
@@ -493,11 +489,7 @@ class Collection(Resource):
             if col_name == 'id':
                 id_name = id_number_to_name(value)
             elif col_name in self.table.attributes_by_name:
-                col = self.table.attributes_by_name[col_name]
-                if col.type_ == Json:  # Should we use a virtual function?
-                    attributes[col_name] = loads(value)
-                else:
-                    attributes[col_name] = value
+                attributes[col_name] = value
             else:  # col_name is a lfkey
                 rel = self.table.relationship_by_lfkey[col_name]
                 if value:
