@@ -22,7 +22,6 @@
 
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
-from json import loads
 
 from asyncpg.exceptions import (
     CheckViolationError,
@@ -47,7 +46,6 @@ from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.postgres import convert_violation_error
 from ajsonapi.responses import document_response, no_content_response
-from ajsonapi.types import Json
 from ajsonapi.uri.collection import (
     Collection,
     VerifyRelationshipIdsEnvironment,
@@ -255,11 +253,7 @@ class Object(Resource):
             if col_name == 'id':
                 continue
             if col_name in self.table.attributes_by_name:
-                col = self.table.attributes_by_name[col_name]
-                if col.type_ == Json:  # Should we use a virtual function?
-                    attributes[col_name] = loads(value)
-                else:
-                    attributes[col_name] = value
+                attributes[col_name] = value
             else:  # col_name is a lfkey
                 rel = self.table.relationship_by_lfkey[col_name]
                 relationships[rel.name] = self.to_relationships(rel, value)
