@@ -327,30 +327,23 @@ class OneToManyRelatedResource(ToManyRelatedResource):
         else:
             columns = (str(col) for col in rtable.columns)
         # We could remove rfkey because we know it already
+
         filters = env.query['filters']
-        sort = env.query['sort']
         if filters:
-            if sort:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE {self.relationship.rfkey} = $1 AND '
-                        f'{" AND ".join(filters)} '
-                        f'ORDER BY {", ".join(sort)}')
-            else:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE {self.relationship.rfkey} = $1 AND '
-                        f'{" AND ".join(filters)}')
+            where_clause = (f' WHERE {self.relationship.rfkey} = $1 AND '
+                            f'{" AND ".join(filters)}')
         else:
-            if sort:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE {self.relationship.rfkey} = $1 '
-                        f'ORDER BY {", ".join(sort)}')
-            else:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE {self.relationship.rfkey} = $1')
+            where_clause = f' WHERE {self.relationship.rfkey} = $1'
+
+        sort = env.query['sort']
+        if sort:
+            order_by_clause = f' ORDER BY {", ".join(sort)}'
+        else:
+            order_by_clause = ''
+
+        stmt = (f'SELECT {", ".join(columns)} '
+                f'FROM data.{self.relationship.rtable.name}'
+                f'{where_clause}{order_by_clause}')
         async with env.lock:
             log.debug(f'{stmt}: {self.id.number}')
             records = await env.connection.fetch(stmt, self.id.number)
@@ -377,42 +370,29 @@ class ManyToManyRelatedResource(ToManyRelatedResource):
                                      if col in query_fields[rtable.collection]))
         else:
             columns = (str(col) for col in rtable.columns)
+
         filters = env.query['filters']
-        sort = env.query['sort']
         if filters:
-            if sort:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE id IN ('
-                        f' SELECT {self.relationship.rafkey}'
-                        f' FROM data.{self.relationship.atable.name}'
-                        f' WHERE {self.relationship.lafkey} = $1) AND'
-                        f' {" AND ".join(filters)} '
-                        f'ORDER BY {", ".join(sort)}')
-            else:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE id IN ('
-                        f' SELECT {self.relationship.rafkey}'
-                        f' FROM data.{self.relationship.atable.name}'
-                        f' WHERE {self.relationship.lafkey} = $1) AND'
-                        f' {" AND ".join(filters)}')
+            where_clause = (f' WHERE id IN ('
+                            f' SELECT {self.relationship.rafkey}'
+                            f' FROM data.{self.relationship.atable.name}'
+                            f' WHERE {self.relationship.lafkey} = $1) AND'
+                            f' {" AND ".join(filters)}')
         else:
-            if sort:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE id IN ('
-                        f' SELECT {self.relationship.rafkey}'
-                        f' FROM data.{self.relationship.atable.name}'
-                        f' WHERE {self.relationship.lafkey} = $1) '
-                        f'ORDER BY {", ".join(sort)}')
-            else:
-                stmt = (f'SELECT {", ".join(columns)} '
-                        f'FROM data.{self.relationship.rtable.name} '
-                        f'WHERE id IN ('
-                        f' SELECT {self.relationship.rafkey}'
-                        f' FROM data.{self.relationship.atable.name}'
-                        f' WHERE {self.relationship.lafkey} = $1)')
+            where_clause = (f' WHERE id IN ('
+                            f' SELECT {self.relationship.rafkey}'
+                            f' FROM data.{self.relationship.atable.name}'
+                            f' WHERE {self.relationship.lafkey} = $1)')
+
+        sort = env.query['sort']
+        if sort:
+            order_by_clause = f' ORDER BY {", ".join(sort)}'
+        else:
+            order_by_clause = ''
+
+        stmt = (f'SELECT {", ".join(columns)} '
+                f'FROM data.{self.relationship.rtable.name}'
+                f'{where_clause}{order_by_clause}')
         async with env.lock:
             log.debug(f'{stmt}: {self.id.number}')
             records = await env.connection.fetch(stmt, self.id.number)
