@@ -167,7 +167,7 @@ class Relationship(Resource):
 
     async def verify_id_exists(self, connection):
         """Raises an exception in case the id in the URL does not exist."""
-        stmt = f'SELECT FROM {self.table.name} WHERE id=$1'
+        stmt = f'SELECT FROM data.{self.table.name} WHERE id=$1'
         record = await connection.fetchrow(stmt, self.id.number)
         if record is None:
             raise ErrorsException([
@@ -260,7 +260,7 @@ class OneToOneLocalRelationship(ToOneRelationship):
 
     async def get_relationship_data(self, env):
         stmt = (f'SELECT {self.relationship.lfkey} '
-                f'FROM {self.table.name} '
+                f'FROM data.{self.table.name} '
                 f'WHERE id=$1')
         async with self.table.pool.acquire() as connection:
             log.debug(f'{stmt}: {self.id.number}')
@@ -280,7 +280,7 @@ class OneToOneLocalRelationship(ToOneRelationship):
 
     async def patch_execute(self, data_id):
         # Need to remove other lfkeys that point to data_id_number!
-        stmt = (f'UPDATE {self.relationship.table.name} '
+        stmt = (f'UPDATE data.{self.relationship.table.name} '
                 f'SET {self.relationship.lfkey} = $1 '
                 f'WHERE id=$2')
         if data_id is None:
@@ -314,7 +314,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
 
     async def get_relationship_data(self, env):
         stmt = (f'SELECT id '
-                f'FROM {self.relationship.rtable.name} '
+                f'FROM data.{self.relationship.rtable.name} '
                 f'WHERE {self.relationship.rfkey}=$1')
         async with self.table.pool.acquire() as connection:
             async with connection.transaction():
@@ -330,7 +330,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
         }
 
     async def patch_execute(self, data_id):
-        stmt_remove = (f'UPDATE {self.relationship.rtable.name} '
+        stmt_remove = (f'UPDATE data.{self.relationship.rtable.name} '
                        f'SET {self.relationship.rfkey} = NULL '
                        f'WHERE {self.relationship.rfkey}=$1')
         async with self.table.pool.acquire() as connection:
@@ -338,7 +338,7 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                 log.debug(f'{stmt_remove}: {self.id.number}')
                 await connection.execute(stmt_remove, self.id.number)
                 if data_id:
-                    stmt_add = (f'UPDATE {self.relationship.rtable.name} '
+                    stmt_add = (f'UPDATE data.{self.relationship.rtable.name} '
                                 f'SET {self.relationship.rfkey} = $1 '
                                 f'WHERE id=$2 AND '
                                 f'({self.relationship.rfkey} IS NULL OR '
@@ -349,10 +349,11 @@ class OneToOneRemoteRelationship(ToOneRelationship):
                         result = await connection.execute(
                             stmt_add, self.id.number, data_id.number)
                         if result == 'UPDATE 0':
-                            stmt_verify = (f'SELECT '
-                                           f'FROM'
-                                           f' {self.relationship.rtable.name} '
-                                           f'WHERE id=$1')
+                            stmt_verify = (
+                                f'SELECT '
+                                f'FROM'
+                                f' data.{self.relationship.rtable.name} '
+                                f'WHERE id=$1')
                             log.debug(stmt_verify)
                             records = await connection.fetch(
                                 stmt_verify, data_id.number)
@@ -377,7 +378,7 @@ class ManyToOneRelationship(ToOneRelationship):
 
     async def get_relationship_data(self, env):
         stmt = (f'SELECT {self.relationship.lfkey} '
-                f'FROM {self.table.name} '
+                f'FROM data.{self.table.name} '
                 f'WHERE id=$1')
         async with self.table.pool.acquire() as connection:
             log.debug(f'{stmt}: {self.id.number}')
@@ -396,7 +397,7 @@ class ManyToOneRelationship(ToOneRelationship):
         }
 
     async def patch_execute(self, data_id):
-        stmt = (f'UPDATE {self.table.name} '
+        stmt = (f'UPDATE data.{self.table.name} '
                 f'SET {self.relationship.lfkey} = $1 '
                 f'WHERE id=$2')
         if data_id is None:
@@ -509,7 +510,7 @@ class OneToManyRelationship(ToManyRelationship):
 
     async def get_relationship_data(self, env):
         stmt = (f'SELECT id '
-                f'FROM {self.relationship.rtable.name} '
+                f'FROM data.{self.relationship.rtable.name} '
                 f'WHERE {self.relationship.rfkey}=$1')
         async with self.table.pool.acquire() as connection:
             async with connection.transaction():
@@ -525,7 +526,7 @@ class OneToManyRelationship(ToManyRelationship):
         } for record in records]
 
     async def patch_execute(self, data_ids):
-        stmt_remove = (f'UPDATE {self.relationship.rtable.name} '
+        stmt_remove = (f'UPDATE data.{self.relationship.rtable.name} '
                        f'SET {self.relationship.rfkey} = NULL '
                        f'WHERE {self.relationship.rfkey}=$1')
         async with self.table.pool.acquire() as connection:
@@ -533,7 +534,7 @@ class OneToManyRelationship(ToManyRelationship):
                 log.debug(f'{stmt_remove}: {self.id.number}')
                 await connection.execute(stmt_remove, self.id.number)
                 if data_ids:
-                    stmt_add = (f'UPDATE {self.relationship.rtable.name} '
+                    stmt_add = (f'UPDATE data.{self.relationship.rtable.name} '
                                 f'SET {self.relationship.rfkey} = $1 '
                                 f'WHERE id=any($2::UUID[])')
                     data_id_numbers = [data_id.number for data_id in data_ids]
@@ -543,10 +544,11 @@ class OneToManyRelationship(ToManyRelationship):
                         result = await connection.execute(
                             stmt_add, self.id.number, data_id_numbers)
                         if result != f'UPDATE {len(data_ids)}':
-                            stmt_verify = (f'SELECT id '
-                                           f'FROM'
-                                           f' {self.relationship.rtable.name} '
-                                           f'WHERE id=ANY($1::UUID[])')
+                            stmt_verify = (
+                                f'SELECT id '
+                                f'FROM'
+                                f' data.{self.relationship.rtable.name} '
+                                f'WHERE id=ANY($1::UUID[])')
                             log.debug(stmt_verify)
                             records = await connection.fetch(
                                 stmt_verify, data_id_numbers)
@@ -568,7 +570,7 @@ class OneToManyRelationship(ToManyRelationship):
 
     async def post_execute(self, data_ids):
         if data_ids:
-            stmt = (f'UPDATE {self.relationship.rtable.name} '
+            stmt = (f'UPDATE data.{self.relationship.rtable.name} '
                     f'SET {self.relationship.rfkey} = $1 '
                     f'WHERE id=ANY($2::UUID[])')
             data_id_numbers = [data_id.number for data_id in data_ids]
@@ -585,9 +587,10 @@ class OneToManyRelationship(ToManyRelationship):
                                 f'/{self.collection.name}/{self.id.name}')
                         ]) from exc
                     if result != f'UPDATE {len(data_ids)}':
-                        stmt_verify = (f'SELECT id '
-                                       f'FROM {self.relationship.rtable.name} '
-                                       f'WHERE id=ANY($1::UUID[])')
+                        stmt_verify = (
+                            f'SELECT id '
+                            f'FROM data.{self.relationship.rtable.name} '
+                            f'WHERE id=ANY($1::UUID[])')
                         log.debug(f'{stmt_verify}: {data_id_numbers}')
                         records = await connection.fetch(
                             stmt_verify, data_id_numbers)
@@ -605,7 +608,7 @@ class OneToManyRelationship(ToManyRelationship):
 
     async def delete_execute(self, data_ids):
         if data_ids:
-            stmt = (f'UPDATE {self.relationship.rtable.name} '
+            stmt = (f'UPDATE data.{self.relationship.rtable.name} '
                     f'SET {self.relationship.rfkey} = NULL '
                     f'WHERE {self.relationship.rfkey}=$1 AND '
                     f'id=ANY($2::UUID[])')
@@ -629,7 +632,7 @@ class ManyToManyRelationship(ToManyRelationship):
 
     async def get_relationship_data(self, env):
         stmt = (f'SELECT {self.relationship.rafkey} '
-                f'FROM {self.relationship.atable.name} '
+                f'FROM data.{self.relationship.atable.name} '
                 f'WHERE {self.relationship.lafkey}=$1')
         async with self.table.pool.acquire() as connection:
             async with connection.transaction():
@@ -645,9 +648,9 @@ class ManyToManyRelationship(ToManyRelationship):
         } for record in records]
 
     async def patch_execute(self, data_ids):
-        stmt_remove = (f'DELETE FROM {self.relationship.atable.name} '
+        stmt_remove = (f'DELETE FROM data.{self.relationship.atable.name} '
                        f'WHERE {self.relationship.lafkey}=$1')
-        stmt_add = (f'INSERT INTO {self.relationship.atable.name} '
+        stmt_add = (f'INSERT INTO data.{self.relationship.atable.name} '
                     f'({self.relationship.lafkey}, '
                     f'{self.relationship.rafkey}) '
                     f'VALUES ($1, $2)')
@@ -668,10 +671,10 @@ class ManyToManyRelationship(ToManyRelationship):
     async def post_execute(self, data_ids):
         if data_ids:
             # To prevent duplicates, we first remove any existing associations
-            stmt_remove = (f'DELETE FROM {self.relationship.atable.name} '
+            stmt_remove = (f'DELETE FROM data.{self.relationship.atable.name} '
                            f'WHERE {self.relationship.lafkey}=$1 AND '
                            f'{self.relationship.rafkey}=ANY($2::UUID[])')
-            stmt_add = (f'INSERT INTO {self.relationship.atable.name} '
+            stmt_add = (f'INSERT INTO data.{self.relationship.atable.name} '
                         f'({self.relationship.lafkey}, '
                         f'{self.relationship.rafkey}) '
                         f'VALUES ($1, $2)')
@@ -698,7 +701,7 @@ class ManyToManyRelationship(ToManyRelationship):
 
     async def delete_execute(self, data_ids):
         if data_ids:
-            stmt = (f'DELETE FROM {self.relationship.atable.name} '
+            stmt = (f'DELETE FROM data.{self.relationship.atable.name} '
                     f'WHERE {self.relationship.lafkey}=$1 AND '
                     f'{self.relationship.rafkey}=ANY($2::UUID[])')
             data_id_numbers = [data_id.number for data_id in data_ids]
@@ -726,7 +729,7 @@ class ManyToManyRelationship(ToManyRelationship):
         # groups[0] == self.relationship.rafkey
 
         stmt_verify = (f'SELECT {self.relationship.rafkey} '
-                       f'FROM {self.relationship.atable.name} '
+                       f'FROM data.{self.relationship.atable.name} '
                        f'WHERE {self.relationship.lafkey}=$1')
         log.debug(f'{stmt_verify}: {self.id.number}')
         records = await connection.fetch(stmt_verify, self.id.number)
